import i18n from 'phovea_core/src/i18n';
var globalErrorTemplate = function (details) { return details; };
/**
 * sets the template function for generating the error details in a error dialog
 * @param {(details: string) => string} template
 */
export function setGlobalErrorTemplate(template) {
    globalErrorTemplate = template;
}
/**
 * Use this modal dialog to show errors that were catched when an XHR request in a promise fails.
 * The dialog returns a promise that is resolved when the dialog is closed.
 * You can use that to clean up things in an error case.
 *
 * Usage:
 * ```
 * Promise(...)
 * .then(() => { ... }) //success
 * .catch(showErrorModalDialog) // open error dialog
 * .then((xhr) => { ... }); // do something after the error dialog has been closed
 * ```
 *
 * @param error
 * @returns {Promise<any>|Promise}
 */
export function showErrorModalDialog(error, additionalCSSClasses) {
    if (additionalCSSClasses === void 0) { additionalCSSClasses = ''; }
    function commonDialog(title, body) {
        // lazy import
        return System.import('./dialogs').then(function (_a) {
            var generateDialog = _a.generateDialog;
            return new Promise(function (resolve, reject) {
                var dialog = generateDialog(title, i18n.t('phovea:ui.dismiss'), additionalCSSClasses);
                dialog.body.innerHTML = globalErrorTemplate(body);
                dialog.onSubmit(function () {
                    dialog.hide();
                    return false;
                });
                dialog.onHide(function () {
                    reject(error);
                    dialog.destroy();
                });
                dialog.show();
            });
        });
    }
    if (error instanceof Response || error.response instanceof Response) {
        var xhr_1 = error instanceof Response ? error : error.response;
        return xhr_1.text().then(function (body) {
            var title = i18n.t('phovea:ui.errorHeader', { status: xhr_1.status, statusText: xhr_1.statusText });
            if (xhr_1.status !== 400) {
                body = body + "<hr>\n        " + i18n.t('phovea:ui.errorBody') + "<br><a href=\"" + xhr_1.url + "\" target=\"_blank\">" + ((xhr_1.url.length > 100) ? xhr_1.url.substring(0, 100) + '...' : xhr_1.url) + "</a>";
            }
            return commonDialog(title, body);
        });
    }
    else if (error instanceof Error) {
        return commonDialog(error.name, error.message);
    }
    else {
        return commonDialog(i18n.t('phovea:ui.unknownError'), error.toString());
    }
}
//# sourceMappingURL=errors.js.map